@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -9,6 +9,8 @@
 #include "utils/utils.h"
 #include "model/deblistmodel.h"
 #include "model/dependgraph.h"
+#include "model/packageanalyzer.h"
+#include "singleInstallerApplication.h"
 
 #include <DRecentManager>
 
@@ -95,19 +97,197 @@ void PackagesManager::selectedIndexRow(int row)
         emit signalMultDependPackages(m_dependsPackages.value(m_packageMd5[row]), installWineDepends);
 }
 
-Backend *init_backend()
+int PackagesManager::checkInstallStatus(const QString &package_path)
 {
-    Backend *backend = new Backend;
+    DebFile debFile(package_path);
+    if (!debFile.isValid())
+        return DebListModel::NotInstalled;
+    const QString packageName = debFile.packageName();
+    const QString packageArch = debFile.architecture();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
+    if (!backend) {
+        qWarning() << "Failed to load libqapt backend";
+        return DebListModel::NotInstalled;
+    }
+    Package *package = packageWithArch(packageName, packageArch);
 
-    if (backend->init())
-        return backend;
 
-    qFatal("%s", backend->initErrorMessage().toStdString().c_str());
+    if (!package)
+        return DebListModel::NotInstalled;
+
+    const QString installedVersion = package->installedVersion();
+    package = nullptr;
+    if (installedVersion.isEmpty())
+        return DebListModel::NotInstalled;
+
+    const QString packageVersion = debFile.version();
+    const int result = Package::compareVersion(packageVersion, installedVersion);
+
+    int ret;
+    if (result == 0)
+        ret = DebListModel::InstalledSameVersion;
+    else if (result < 0)
+        ret = DebListModel::InstalledLaterVersion;
+    else
+        ret = DebListModel::InstalledEarlierVersion;
+
+    return ret;
+
+}
+
+PackageDependsStatus PackagesManager::checkDependsStatus(const QString &package_path)
+{
+    DebFile debFile(package_path);
+    if (!debFile.isValid())
+        return PackageDependsStatus::_break("");
+    m_currentPkgName = debFile.packageName();
+    m_orDepends.clear();
+    m_checkedOrDependsStatus.clear();
+    m_unCheckedOrDepends.clear();
+    m_dependsInfo.clear();
+    //用debFile.packageName()无法打开deb文件，故替换成debFile.filePath()
+    //更新m_dependsInfo
+    getPackageOrDepends(debFile.filePath(), debFile.architecture(), true);
+
+    const QString architecture = debFile.architecture();
+    PackageDependsStatus dependsStatus = PackageDependsStatus::ok();
+
+    if (isBlackApplication(debFile.packageName())) {
+        dependsStatus.status  = DebListModel::Prohibit;
+        dependsStatus.package = debFile.packageName();
+        qWarning() << debFile.packageName() << "In the blacklist";
+        return dependsStatus;
+    }
+
+    if (isArchErrorQstring(package_path)) {
+        dependsStatus.status = DebListModel::ArchBreak;       //添加ArchBreak错误。
+        dependsStatus.package = debFile.packageName();
+        QString packageName = debFile.packageName();
+        return PackageDependsStatus::_break(packageName);
+    }
+
+    // conflicts
+    const ConflictResult debConflitsResult = isConflictSatisfy(architecture, debFile.conflicts(), debFile.replaces());
+
+    if (!debConflitsResult.is_ok()) {
+        qWarning() << "PackagesManager:" << "depends break because conflict" << debFile.packageName();
+        dependsStatus.package = debConflitsResult.unwrap();
+        dependsStatus.status = DebListModel::DependsBreak;
+    } else {
+        const ConflictResult localConflictsResult =
+            isInstalledConflict(debFile.packageName(), debFile.version(), architecture);
+        if (!localConflictsResult.is_ok()) {
+            qWarning() << "PackagesManager:" << "depends break because conflict with local package" << debFile.packageName();
+            dependsStatus.package = localConflictsResult.unwrap();
+            dependsStatus.status = DebListModel::DependsBreak;
+        } else {
+            QSet<QString> choose_set;
+            choose_set << debFile.packageName();
+            QStringList dependList;
+            bool isWineApplication = false;             //判断是否是wine应用
+            for (auto ditem : debFile.depends()) {      //每一个list中的关系是或的关系
+                for (auto dinfo : ditem) {
+                    Package *depend = packageWithArch(dinfo.packageName(), debFile.architecture());
+                    if (depend) {
+                        if (depend->name() == "deepin-elf-verify")   //deepi-elf-verify 是amd64架构非i386
+                            dependList << depend->name();
+                        else
+                            dependList << depend->name() + ":" + depend->architecture();
+
+                        depend = nullptr;
+
+                        if (dinfo.packageName().contains("deepin-wine"))             // 如果依赖中出现deepin-wine字段。则是wine应用
+                            isWineApplication = true;
+
+                    }
+                }
+            }
+            installWineDepends = false; //标记wine依赖下载线程开启
+            isDependsExists = false; //标记多架构依赖冲突
+            m_pair.first.clear(); //清空available依赖
+            m_pair.second.clear(); //清空broken依赖
+            if (m_dependsPackages.contains(m_currentPkgMd5))
+                m_dependsPackages.remove(m_currentPkgMd5);
+
+            dependsStatus = checkDependsPackageStatus(choose_set, debFile.architecture(), debFile.depends());
+            // 删除无用冗余的日志
+            //由于卸载p7zip会导致wine依赖被卸载，再次安装会造成应用闪退，因此判断的标准改为依赖不满足即调用pkexec
+            //wine应用+非wine依赖不满足即可导致出问题
+            do {
+                if (isWineApplication && dependsStatus.status != DebListModel::DependsOk) {               //增加是否是wine应用的判断
+                    //额外判断wine依赖是否已安装，同时剔除非wine依赖
+                    auto removedIter = std::remove_if(dependList.begin(), dependList.end(), [&debFile, this](const QString & eachDepend) {
+                        if (!eachDepend.contains("deepin-wine")) {
+                            return true;
+                        }
+                        auto package = packageWithArch(eachDepend, debFile.architecture());
+                        return !package->installedVersion().isEmpty();
+                    });
+                    dependList.erase(removedIter, dependList.end());
+                    if (dependList.isEmpty()) { //所有的wine依赖均已安装
+                        break;
+                    }
+                    dependsStatus.status = DebListModel::DependsBreak;                                    //只要是下载，默认当前wine应用依赖为break
+                }
+            } while (0);
+        }
+    }
+    if (dependsStatus.isBreak())
+        Q_ASSERT(!dependsStatus.package.isEmpty());
+
+    return dependsStatus;
+}
+
+QStringList PackagesManager::getPackageInfo(const QString &package_path)
+{
+    QStringList value_list;
+    const DebFile deb(package_path);
+    if (!deb.isValid())
+        return value_list;
+    QString packageName = deb.packageName(); //包名
+    QString filePath = deb.filePath(); //包的路径
+    QString version = deb.version(); //包的版本
+    QString architecture = deb.architecture(); //包可用的架构
+    QString shortDescription = deb.shortDescription(); //包的短描述
+    QString longDescription = deb.longDescription(); //包的长描述
+    value_list << packageName << filePath << version << architecture << shortDescription << longDescription;
+    return value_list;
+}
+
+QString PackagesManager::checkPackageValid(const QStringList &package_path)
+{
+    for (QString debPackage : package_path) {                 //通过循环添加所有的包
+        QStorageInfo info(debPackage);                               //获取路径信息
+        QString device = info.device();   //获取设备信息
+        // 处理包不在本地的情况。
+        if (!device.startsWith("/dev/") && device != QString::fromLocal8Bit("tmpfs")) {  //判断路径信息是不是本地路径
+            return "You can only install local deb packages";
+        }
+        QString debPkg = debPackage;
+        //处理package文件路径相关问题
+        debPackage = dealPackagePath(debPackage);
+
+        QApt::DebFile pkgFile(debPackage);
+        //判断当前文件是否是无效文件
+        if (!pkgFile.isValid()) {
+            return "The deb package may be broken";
+        }
+        //获取当前文件的md5的值,防止重复添加
+        //在checkInvalid中已经获取过md5,避免2次获取影响性能
+        QByteArray md5 = m_allPackages.value(debPkg);
+        if (md5.isEmpty())
+            md5 = pkgFile.md5Sum();
+
+        // 如果当前已经存在此md5的包,则说明此包已经添加到程序中
+        if (m_appendedPackagesMd5.contains(md5)) {
+            return "The deb package Already Added";
+        }
+    }
+    return "";
 }
 
 PackagesManager::PackagesManager(QObject *parent)
     : QObject(parent)
-    , m_backendFuture(QtConcurrent::run(init_backend))
 {
     m_installWineThread = new DealDependThread();
     connect(m_installWineThread, &DealDependThread::signalDependResult, this, &PackagesManager::slotDealDependResult);
@@ -122,6 +302,9 @@ PackagesManager::PackagesManager(QObject *parent)
     //转发无效包的信号
     connect(m_pAddPackageThread, &AddPackageThread::signalInvalidPackage, this, &PackagesManager::signalInvalidPackage);
 
+    //转发无效ddim的信号
+    connect(m_pAddPackageThread, &AddPackageThread::signalNotDdimProcess, this, &PackagesManager::signalNotDdimProcess);
+
     //转发不是本地包的信号
     connect(m_pAddPackageThread, &AddPackageThread::signalNotLocalPackage, this, &PackagesManager::signalNotLocalPackage);
 
@@ -136,7 +319,7 @@ PackagesManager::PackagesManager(QObject *parent)
 
 bool PackagesManager::isBackendReady()
 {
-    return m_backendFuture.isFinished();
+    return PackageAnalyzer::instance().isBackendReady();
 }
 
 bool PackagesManager::isArchError(const int idx)
@@ -144,7 +327,7 @@ bool PackagesManager::isArchError(const int idx)
     if (idx < 0 || idx >= m_preparedPackages.size())
         return true;
 
-    Backend *backend = m_backendFuture.result();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
     if (!backend) {
         qWarning() << "Failed to load libqapt backend";
         return true;
@@ -164,6 +347,28 @@ bool PackagesManager::isArchError(const int idx)
     return architectures;
 }
 
+bool PackagesManager::isArchErrorQstring(const QString &package_name)
+{
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
+    if (!backend) {
+        qWarning() << "Failed to load libqapt backend";
+        return true;
+    }
+    DebFile deb(package_name);
+
+    if (!deb.isValid())
+        return false;
+
+    const QString arch = deb.architecture();
+
+    if ("all" == arch || "any" == arch)
+        return false;
+
+    bool architectures = !backend->architectures().contains(deb.architecture());
+
+    return architectures;
+}
+
 const ConflictResult PackagesManager::packageConflictStat(const int index)
 {
     if (index < 0 || index >= m_preparedPackages.size())
@@ -201,7 +406,7 @@ const ConflictResult PackagesManager::isInstalledConflict(const QString &package
     static QList<QPair<QLatin1String, DependencyInfo>> sysConflicts;
 
     if (sysConflicts.isEmpty()) {
-        Backend *backend = m_backendFuture.result();
+        Backend *backend = PackageAnalyzer::instance().backendPtr();
         for (Package *pkg : backend->availablePackages()) {
             if (!pkg)
                 continue;
@@ -251,6 +456,90 @@ const ConflictResult PackagesManager::isInstalledConflict(const QString &package
     return ConflictResult::ok(QString());
 }
 
+const ConflictResult PackagesManager::isConflictSatisfy(const QString &arch,
+                                                        const QList<DependencyItem> &conflicts,
+                                                        const QList<DependencyItem> &replaces)
+{
+    for (const auto &conflict_list : conflicts) {
+        for (const auto &conflict : conflict_list) {
+            const QString name = conflict.packageName();
+
+            //修复依赖中 conflict与provides 存在相同 virtual package
+            //此前使用packageWithArch, 在package打包失败时，会寻找virtual package的提供的其他包
+            //在dde-daemon中 lastore-daemon-migration与dde-daemon为conflict,
+            //lastore-daemon-migration 又提供了dde-daemon,导致最后打成的包不是virtual package而是provides的包
+            Backend *backend = PackageAnalyzer::instance().backendPtr();
+            if (!backend)
+                return ConflictResult::err(QString());
+            Package *package = backend->package(name);
+
+            if (!package)
+                continue;
+
+            if (!package->isInstalled()) {
+                package = nullptr;
+                continue;
+            }
+            // arch error, conflicts
+            if (!isArchMatches(arch, package->architecture(), package->multiArchType())) {
+                qWarning() << "PackagesManager:" << "conflicts package installed: "
+                           << arch << package->name() << package->architecture()
+                           << package->multiArchTypeString();
+                package = nullptr;
+                return ConflictResult::err(name);
+            }
+
+            const QString conflict_version = conflict.packageVersion();
+            const QString installed_version = package->installedVersion();
+            const auto type = conflict.relationType();
+            const auto result = Package::compareVersion(installed_version, conflict_version);
+
+            // not match, ok
+            if (!dependencyVersionMatch(result, type)) {
+                package = nullptr;
+                continue;
+            }
+            // test package
+            const QString mirror_version = package->availableVersion();
+
+            //删除版本相同比较，如果安装且版本符合则判断冲突，此前逻辑存在问题
+            // mirror version is also break
+            const auto mirror_result = Package::compareVersion(mirror_version, conflict_version);
+            if (dependencyVersionMatch(mirror_result, type) && name != m_currentPkgName) { //此处即可确认冲突成立
+                //额外判断是否会替换此包
+                bool conflict_yes = true;
+                for (auto replace_list : replaces) {
+                    for (auto replace : replace_list) {
+                        if (replace.packageName() == name) { //包名符合
+                            auto replaceType = replace.relationType(); //提取版本号规则
+                            auto versionCompare = Package::compareVersion(installed_version, replace.packageVersion()); //比较版本号
+                            if (dependencyVersionMatch(versionCompare, replaceType)) { //如果版本号符合要求，即判定replace成立
+                                conflict_yes = false;
+                                break;
+                            }
+                        }
+                    }
+                    if (!conflict_yes) {
+                        break;
+                    }
+                }
+
+                if (!conflict_yes) {
+                    package = nullptr;
+                    continue;
+                }
+
+                qWarning() << "PackagesManager:" <<  "conflicts package installed: "
+                           << arch << package->name() << package->architecture()
+                           << package->multiArchTypeString() << mirror_version << conflict_version;
+                return ConflictResult::err(name);
+            }
+
+        }
+    }
+    return ConflictResult::ok(QString());
+}
+
 const ConflictResult PackagesManager::isConflictSatisfy(const QString &arch, const QList<DependencyItem> &conflicts)
 {
     for (const auto &conflict_list : conflicts) {
@@ -261,7 +550,7 @@ const ConflictResult PackagesManager::isConflictSatisfy(const QString &arch, con
             //此前使用packageWithArch, 在package打包失败时，会寻找virtual package的提供的其他包
             //在dde-daemon中 lastore-daemon-migration与dde-daemon为conflict,
             //lastore-daemon-migration 又提供了dde-daemon,导致最后打成的包不是virtual package而是provides的包
-            Backend *backend = m_backendFuture.result();
+            Backend *backend = PackageAnalyzer::instance().backendPtr();
             if (!backend)
                 return ConflictResult::err(QString());
             Package *package = backend->package(name);
@@ -329,7 +618,7 @@ int PackagesManager::packageInstallStatus(const int index)
         return DebListModel::NotInstalled;
     const QString packageName = debFile.packageName();
     const QString packageArch = debFile.architecture();
-    Backend *backend = m_backendFuture.result();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
     if (!backend) {
         qWarning() << "Failed to load libqapt backend";
         return DebListModel::NotInstalled;
@@ -363,7 +652,7 @@ int PackagesManager::packageInstallStatus(const int index)
     return ret;
 }
 
-void PackagesManager::slotDealDependResult(int iAuthRes, int iIndex, QString dependName)
+void PackagesManager::slotDealDependResult(int iAuthRes, int iIndex, const QString &dependName)
 {
     if (iIndex < 0 || iIndex > m_preparedPackages.size())
         return;
@@ -424,7 +713,7 @@ QByteArray PackagesManager::getPackageMd5(const int index)
 PackageDependsStatus PackagesManager::getPackageDependsStatus(const int index)
 {
     //提前获取需要的md5
-    if (index < 0 || index > m_preparedPackages.size()) {
+    if (index < 0 || index >= m_preparedPackages.size()) {
         qWarning() << "invalid param index";
         return PackageDependsStatus::_break("");
     }
@@ -462,8 +751,7 @@ PackageDependsStatus PackagesManager::getPackageDependsStatus(const int index)
         dependsStatus.status = DebListModel::ArchBreak;       //添加ArchBreak错误。
         dependsStatus.package = debFile.packageName();
         m_packageMd5DependsStatus.insert(currentPackageMd5, dependsStatus);//更换依赖的存储方式
-        QString packageName = debFile.packageName();
-        return PackageDependsStatus::_break(packageName);
+        return dependsStatus;
     }
 
     // conflicts
@@ -516,15 +804,15 @@ PackageDependsStatus PackagesManager::getPackageDependsStatus(const int index)
             do {
                 if (isWineApplication && dependsStatus.status != DebListModel::DependsOk) {               //增加是否是wine应用的判断
                     //额外判断wine依赖是否已安装，同时剔除非wine依赖
-                    auto removedIter = std::remove_if(dependList.begin(), dependList.end(), [&debFile, this](const QString &eachDepend){
-                        if(!eachDepend.contains("deepin-wine")) {
+                    auto removedIter = std::remove_if(dependList.begin(), dependList.end(), [&debFile, this](const QString & eachDepend) {
+                        if (!eachDepend.contains("deepin-wine")) {
                             return true;
                         }
                         auto package = packageWithArch(eachDepend, debFile.architecture());
                         return !package->installedVersion().isEmpty();
                     });
                     dependList.erase(removedIter, dependList.end());
-                    if(dependList.isEmpty()) { //所有的wine依赖均已安装
+                    if (dependList.isEmpty()) { //所有的wine依赖均已安装
                         break;
                     }
 
@@ -542,7 +830,7 @@ PackageDependsStatus PackagesManager::getPackageDependsStatus(const int index)
                     }
                     dependsStatus.status = DebListModel::DependsBreak;                                    //只要是下载，默认当前wine应用依赖为break
                 }
-            }while(0);
+            } while (0);
         }
     }
     if (dependsStatus.isBreak())
@@ -587,7 +875,7 @@ void PackagesManager::getPackageOrDepends(const QString &package, const QString
     qInfo() << __func__ << controlDepends;
     QStringList dependsList = controlDepends.split(",");
 
-    auto removedIter = std::remove_if(dependsList.begin(), dependsList.end(), [](const QString &str){
+    auto removedIter = std::remove_if(dependsList.begin(), dependsList.end(), [](const QString & str) {
         return !str.contains("|");
     });
     dependsList.erase(removedIter, dependsList.end());
@@ -619,7 +907,7 @@ const QString PackagesManager::packageInstalledVersion(const int index)
         return "";
     const QString packageName = debFile.packageName();
     const QString packageArch = debFile.architecture();
-    Backend *backend = m_backendFuture.result();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
     if (!backend) {
         qWarning() << "libqapt backend loading error";
         return "";
@@ -689,7 +977,7 @@ void PackagesManager::packageCandidateChoose(QSet<QString> &choosed_set, const Q
                 //  修复升级依赖时，因为依赖包版本过低，造成安装循环。
                 // 删除无用冗余的日志
                 if (Package::compareVersion(package->installedVersion(), info.packageVersion()) < 0) {
-                    Backend *backend = m_backendFuture.result();
+                    Backend *backend = PackageAnalyzer::instance().backendPtr();
                     if (!backend) {
                         qWarning() << "libqapt backend loading error";
                         return;
@@ -708,7 +996,7 @@ void PackagesManager::packageCandidateChoose(QSet<QString> &choosed_set, const Q
         } else { // 存在或依赖且当前依赖属于或依赖关系
             bool isInstalling = false;
             for (auto iter = infos.begin(); iter != infos.end(); iter++) {
-                Backend *backend = m_backendFuture.result();
+                Backend *backend = PackageAnalyzer::instance().backendPtr();
                 if (!backend) {
                     qWarning() << "libqapt backend loading error";
                     return;
@@ -729,7 +1017,7 @@ void PackagesManager::packageCandidateChoose(QSet<QString> &choosed_set, const Q
                     choosed_set << choosed_name;
                 } else {
                     if (Package::compareVersion(package->installedVersion(), info.packageVersion()) < 0) {
-                        Backend *backend = m_backendFuture.result();
+                        Backend *backend = PackageAnalyzer::instance().backendPtr();
                         if (!backend)
                             return;
                         Package *updatePackage = backend->package(package->name()
@@ -866,7 +1154,7 @@ void PackagesManager::reset()
     m_dependGraph.reset();
 
     //reloadCache必须要加
-    m_backendFuture.result()->reloadCache();
+    PackageAnalyzer::instance().backendPtr()->reloadCache();
     m_dependsPackages.clear();
 }
 
@@ -885,7 +1173,7 @@ void PackagesManager::resetPackageDependsStatus(const int index)
     }
     // reload backend cache
     //reloadCache必须要加
-    m_backendFuture.result()->reloadCache();
+    PackageAnalyzer::instance().backendPtr()->reloadCache();
     m_packageMd5DependsStatus.remove(currentPackageMd5);  //删除当前包的依赖状态（之后会重新获取此包的依赖状态）
 }
 
@@ -968,7 +1256,7 @@ void PackagesManager::appendPackage(QStringList packages)
 /**
  * @brief AddPackageThread::checkInvalid 检查有效文件的数量
  */
-void PackagesManager::checkInvalid(QStringList packages)
+void PackagesManager::checkInvalid(const QStringList &packages)
 {
     m_allPackages.clear();
     m_validPackageCount = packages.size();
@@ -1013,7 +1301,7 @@ void PackagesManager::checkInvalid(QStringList packages)
  *   true   : 包在本地
  *   fasle  : 文件不在本地
  */
-bool PackagesManager::dealInvalidPackage(QString packagePath)
+bool PackagesManager::dealInvalidPackage(const QString &packagePath)
 {
     QStorageInfo info(packagePath);                               //获取路径信息
 
@@ -1033,25 +1321,26 @@ bool PackagesManager::dealInvalidPackage(QString packagePath)
  *      1： 相对路径             --------> 转化为绝对路径
  *      2： 包的路径中存在空格     --------> 使用软链接，链接到/tmp下
  */
-QString PackagesManager::dealPackagePath(QString packagePath)
+QString PackagesManager::dealPackagePath(const QString &packagePath)
 {
+    auto tempPath = packagePath;
     //判断当前文件路径是否是绝对路径，不是的话转换为绝对路径
-    if (!packagePath.startsWith("/")) {
-        QFileInfo packageAbsolutePath(packagePath);
-        packagePath = packageAbsolutePath.absoluteFilePath();                           //获取绝对路径
+    if (!tempPath.startsWith("/")) {
+        QFileInfo packageAbsolutePath(tempPath);
+        tempPath = packageAbsolutePath.absoluteFilePath();                           //获取绝对路径
         qInfo() << "get AbsolutePath" << packageAbsolutePath.absoluteFilePath();
     }
 
     // 判断当前文件路径中是否存在空格,如果存在则创建软链接并在之后的安装时使用软链接进行访问.
-    if (packagePath.contains(" ")) {
-        QApt::DebFile p(packagePath);
+    if (tempPath.contains(" ")) {
+        QApt::DebFile p(tempPath);
         if (p.isValid()) {
-            packagePath = SymbolicLink(packagePath, p.packageName());
+            tempPath = SymbolicLink(tempPath, p.packageName());
             qWarning() << "PackagesManager:"
-                       << "There are spaces in the path, add a soft link" << packagePath;
+                       << "There are spaces in the path, add a soft link" << tempPath;
         }
     }
-    return packagePath;
+    return tempPath;
 }
 
 /**
@@ -1059,7 +1348,7 @@ QString PackagesManager::dealPackagePath(QString packagePath)
  * @param packages
  * @param allPackageSize
  */
-void PackagesManager::appendNoThread(QStringList packages, int allPackageSize)
+void PackagesManager::appendNoThread(const QStringList &packages, int allPackageSize)
 {
     for (QString debPackage : packages) {                 //通过循环添加所有的包
 
@@ -1070,6 +1359,12 @@ void PackagesManager::appendNoThread(QStringList packages, int allPackageSize)
         //处理package文件路径相关问题
         debPackage = dealPackagePath(debPackage);
 
+        //检测到是ddim文件
+        if (debPackage.endsWith(".ddim")) {
+            emit signalNotDdimProcess();
+            continue;
+        }
+
         QApt::DebFile pkgFile(debPackage);
         //判断当前文件是否是无效文件
         if (!pkgFile.isValid()) {
@@ -1146,11 +1441,11 @@ void PackagesManager::slotAppendPackageFinished()
     emit signalAppendFinished(m_packageMd5);
 }
 
-void PackagesManager::addPackage(int validPkgCount, QString packagePath, QByteArray packageMd5Sum)
+void PackagesManager::addPackage(int validPkgCount, const QString &packagePath, const QByteArray &packageMd5Sum)
 {
     //预先校验包是否有效或是否重复
     DebFile currentDebfile(packagePath);
-    if(!currentDebfile.isValid() || m_appendedPackagesMd5.contains(packageMd5Sum)) {
+    if (!currentDebfile.isValid() || m_appendedPackagesMd5.contains(packageMd5Sum)) {
         return;
     }
 
@@ -1164,12 +1459,12 @@ void PackagesManager::addPackage(int validPkgCount, QString packagePath, QByteAr
     m_preparedPackages = installQueue.first;
     m_packageMd5 = installQueue.second;
     int indexRow = 0;
-    for (;indexRow != m_packageMd5.size();++indexRow) {
-        if(m_packageMd5[indexRow] == packageMd5Sum) {
+    for (; indexRow != m_packageMd5.size(); ++indexRow) {
+        if (m_packageMd5[indexRow] == packageMd5Sum) {
             break;
         }
     }
-    if(indexRow == m_packageMd5.size()) { //error
+    if (indexRow == m_packageMd5.size()) { //error
         return;
     }
 
@@ -1178,7 +1473,7 @@ void PackagesManager::addPackage(int validPkgCount, QString packagePath, QByteAr
     refreshPage(validPkgCount);                     //添加后，根据添加的状态刷新界面
 }
 
-QList<QString> PackagesManager::getAllDepends(const QList<DependencyItem> &depends, QString architecture)
+QList<QString> PackagesManager::getAllDepends(const QList<DependencyItem> &depends, const QString &architecture)
 {
     //检索当前包的所有依赖
     for (const auto &list : depends) {
@@ -1187,12 +1482,12 @@ QList<QString> PackagesManager::getAllDepends(const QList<DependencyItem> &depen
             m_allDependsList << info.packageName() << dList; //存储所有依赖
         }
     }
-    m_allDependsList = m_allDependsList.toSet().toList();
+    m_allDependsList = m_allDependsList.toSet().values();
 
     return m_allDependsList;
 }
 
-QList<QString> PackagesManager::getAllDepends(const QString &packageName, QString architecture)
+QList<QString> PackagesManager::getAllDepends(const QString &packageName, const QString &architecture)
 {
     QList<QString> dDepends; //存储依赖的依赖
     dDepends << packageName;
@@ -1250,12 +1545,11 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
         dependsStatus.minEq(r);
 
         if (!m_unCheckedOrDepends.isEmpty() && r.isBreak()) { //安装包存在或依赖关系且当前依赖状态为break
-            QVector<QString> depends;
             for (auto orDepends : m_unCheckedOrDepends) { //遍历或依赖组，检测当前依赖是否存在或依赖关系
-                depends = orDepends;
                 if (orDepends.contains(info.packageName())) {
                     m_unCheckedOrDepends.removeOne(orDepends);
                     m_checkedOrDependsStatus.insert(info.packageName(), r);
+                    auto depends = orDepends;
                     depends.removeOne(info.packageName()); //将当前依赖从或依赖中删除，检测或依赖中剩余依赖状态
                     qInfo() << depends << orDepends;
                     for (auto otherDepend : depends) {
@@ -1302,10 +1596,29 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
         return PackageDependsStatus::_break(package_name);
     }
 
+    //虚拟包版本号处理步骤
+    QString pkgRealVer = package->version();
+    bool isVirtualPackage = false;
+
+#ifdef ENABLE_VIRTUAL_PACKAGE_ENHANCE
+    if (package->name() != package_name) {
+        auto pkgMap = package->providesListEnhance();
+        auto iter = pkgMap.find(package_name);
+        if (iter != pkgMap.end()) {
+            pkgRealVer = *iter;
+            isVirtualPackage = true;
+        }
+    }
+#endif
+
     const RelationType relation = dependencyInfo.relationType();
-    const QString &installedVersion = package->installedVersion();
+    QString installedVersion = package->installedVersion();
 
     if (!installedVersion.isEmpty()) {
+        if (isVirtualPackage) {
+            installedVersion = pkgRealVer;
+        }
+
         const int result = Package::compareVersion(installedVersion, dependencyInfo.packageVersion());
         if (dependencyVersionMatch(result, relation)) {
             return PackageDependsStatus::ok();
@@ -1330,7 +1643,7 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
             return PackageDependsStatus::_break(package->name());
         }
     } else {
-        const int result = Package::compareVersion(package->version(), dependencyInfo.packageVersion());
+        const int result = Package::compareVersion(pkgRealVer, dependencyInfo.packageVersion());
         if (!dependencyVersionMatch(result, relation)) {
             qWarning() << "PackagesManager:" << "depends break by" << package->name() << package->architecture() << dependencyInfo.packageVersion();
             qWarning() << "PackagesManager:" << "available version not match" << package->version();
@@ -1345,7 +1658,7 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
 
         // check arch conflicts
         if (package->multiArchType() == MultiArchSame) {
-            Backend *backend = m_backendFuture.result();
+            Backend *backend = PackageAnalyzer::instance().backendPtr();
             for (const auto &arch : backend->architectures()) {
                 if (arch == package->architecture())
                     continue;
@@ -1364,7 +1677,7 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
         // let's check conflicts
         if (!isConflictSatisfy(architecture, package).is_ok()) {
 
-            Backend *backend = m_backendFuture.result();
+            Backend *backend = PackageAnalyzer::instance().backendPtr();
             for (auto *availablePackage : backend->availablePackages()) {
                 if (!availablePackage->providesList().contains(package->name())) {
                     availablePackage = nullptr;
@@ -1426,11 +1739,12 @@ const PackageDependsStatus PackagesManager::checkDependsPackageStatus(QSet<QStri
 Package *PackagesManager::packageWithArch(const QString &packageName, const QString &sysArch,
                                           const QString &annotation)
 {
-    Backend *backend = m_backendFuture.result();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
     if (!backend) {
         qWarning() << "Failed to load libqapt backend";
         return nullptr;
     }
+
     Package *package = backend->package(packageName + resolvMultiArchAnnotation(annotation, sysArch));
     // change: 按照当前支持的CPU架构进行打包。取消对deepin-wine的特殊处理
     if (!package)
@@ -1459,7 +1773,7 @@ Package *PackagesManager::packageWithArch(const QString &packageName, const QStr
  * @param packageName 软件包的包名
  * @return 软链接的路径
  */
-QString PackagesManager::SymbolicLink(QString previousName, QString packageName)
+QString PackagesManager::SymbolicLink(const QString &previousName, const QString &packageName)
 {
     if (!mkTempDir()) {//如果创建临时目录失败,则提示
         qWarning() << "PackagesManager:" << "Failed to create temporary folder";
@@ -1488,7 +1802,7 @@ bool PackagesManager::mkTempDir()
  * @param packageName           包的packageName
  * @return                      软链接之后的路径
  */
-QString PackagesManager::link(QString linkPath, QString packageName)
+QString PackagesManager::link(const QString &linkPath, const QString &packageName)
 {
     QFile linkDeb(linkPath);
 
@@ -1556,7 +1870,7 @@ void PackagesManager::getBlackApplications()
     qWarning() << "Black File not Found";
 }
 
-bool PackagesManager::isBlackApplication(QString applicationName)
+bool PackagesManager::isBlackApplication(const QString &applicationName)
 {
     if (m_blackApplicationList.contains(applicationName))
         return true;
@@ -1578,14 +1892,6 @@ PackagesManager::~PackagesManager()
         rmTempDirCount++;
     }
     delete m_installWineThread;
-
-    //先取消当前异步计算的后端。
-    m_backendFuture.cancel();
     delete m_pAddPackageThread;
-
-    Backend *backend = m_backendFuture.result();
-
-    delete backend;
-    backend = nullptr;
 }
 
