@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -67,7 +67,7 @@ public:
      * @return
      */
     static QString resolvMultiArchAnnotation(const QString &annotation, const QString &debArch,
-                                      const int multiArchType = InvalidMultiArchType);
+                                             const int multiArchType = InvalidMultiArchType);
 
     /**
      * @brief dependencyVersionMatch 判断当前依赖版本是否匹配
@@ -83,6 +83,26 @@ public:
      */
     void selectedIndexRow(int row);
 
+    /**
+     * @brief searchPackageInstallInfo 查找指定包安装状态
+     * @param package_path 路径
+     */
+    int checkInstallStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包依赖
+     * @param package_path 包名字
+     */
+    PackageDependsStatus checkDependsStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包信息
+     * @param package_path 包名字
+     */
+    QStringList getPackageInfo(const QString &package_path);
+    /**
+     * @brief checkPackageValid 检查包有效性
+     * @param package_path 包名字
+     */
+    QString checkPackageValid(const QStringList &package_path);
 public slots:
     /**
      * @brief DealDependResult 处理wine依赖下载结果的槽函数
@@ -90,14 +110,14 @@ public slots:
      * @param iIndex    wine应用的下标
      * @param dependName    wine依赖错误的依赖名称
      */
-    void slotDealDependResult(int iAuthRes, int iIndex, QString dependName);
+    void slotDealDependResult(int iAuthRes, int iIndex, const QString &dependName);
 
 //// 依赖下载相关信号
 signals:
     /**
      * @brief DependResult 处理wine依赖下载结果
      */
-    void signalDependResult(int, int, QString);
+    void signalDependResult(int, int, const QString &);
 
     /**
      * @brief enableCloseButton 设置关闭按钮是否可用的信号
@@ -111,6 +131,11 @@ signals:
      */
     void signalInvalidPackage();
 
+    /**
+     * @brief signalNotDdimProcess 非DDIM处理流程
+     */
+    void signalNotDdimProcess();
+
     /**
      * @brief notLocalPackage 包不在本地的信号
      *
@@ -132,13 +157,13 @@ signals:
      * @brief appendFinished 批量安装添加包结束的信号
      * @param packageMd5List 添加后的md5列表
      */
-    void signalAppendFinished(QList<QByteArray> packageMd5List);
+    void signalAppendFinished(const QList<QByteArray> &packageMd5List);
 
     /**
      * @brief packageMd5Changed 添加完成之后更新MD5的列表
      * @param packageMd5List 当前的MD5列表
      */
-    void signalPackageMd5Changed(QList<QByteArray> packageMd5List);
+    void signalPackageMd5Changed(const QList<QByteArray> &packageMd5List);
 
 //// 界面刷新相关信号
 signals:
@@ -185,15 +210,6 @@ public:
      */
     bool isBackendReady();
 
-    /**
-     * @brief backend 获取后端指针
-     * @return  后端的指针
-     */
-    QApt::Backend *backend() const
-    {
-        return m_backendFuture.result();
-    }
-
 //// 包状态相关函数
 public:
 
@@ -213,7 +229,7 @@ public:
      * true: 不符合当前系统架构的要求
      */
     bool isArchError(const int idx);
-
+    bool isArchErrorQstring(const QString &package_name);
 
     /**
      * @brief packageInstallStatus 获取指定index的包的安装状态
@@ -353,6 +369,11 @@ private:
     const ConflictResult isConflictSatisfy(const QString &arch, QApt::Package *package);
     const ConflictResult isConflictSatisfy(const QString &arch, const QList<QApt::DependencyItem> &conflicts);
 
+    //带replaces的检查，如果判定待安装包可以替换冲突包，则认为不构成冲突
+    const ConflictResult isConflictSatisfy(const QString &arch,
+                                           const QList<DependencyItem> &conflicts,
+                                           const QList<DependencyItem> &replaces);
+
 private:
     /**
      * @brief packageWithArch 从指定的架构上打包
@@ -376,7 +397,7 @@ private:
      * @param packageName  当前包的包名
      * @return 创建成功后软链接的全路径
      */
-    QString SymbolicLink(QString previousName, QString packageName);
+    QString SymbolicLink(const QString &previousName, const QString &packageName);
 
     /**
      * @brief link          创建软链接
@@ -384,7 +405,7 @@ private:
      * @param packageName   包名
      * @return  创建软链接之后的路径
      */
-    QString link(QString linkPath, QString packageName);
+    QString link(const QString &linkPath, const QString &packageName);
 
     /**
      * @brief mkTempDir 创建存放软链接的临时路径
@@ -407,7 +428,7 @@ private:
      * @param packagePath   此次添加包的路径
      * @param packageMd5Sum 此次添加的包的md5值
      */
-    void addPackage(int validPkgCount, QString packagePath, QByteArray packageMd5Sum);
+    void addPackage(int validPkgCount, const QString &packagePath, const QByteArray &packageMd5Sum);
 
     /**
      * @brief getAllDepends 获取安装包所有依赖
@@ -415,7 +436,7 @@ private:
      * @param architecture  安装包架构
      * @return
      */
-    QList<QString> getAllDepends(const QList<DependencyItem> &depends,QString architecture);
+    QList<QString> getAllDepends(const QList<DependencyItem> &depends, const QString &architecture);
 
     /**
      * @brief getAllDepends 获取依赖包所有依赖
@@ -423,7 +444,7 @@ private:
      * @param architecture  架构
      * @return
      */
-    QList<QString> getAllDepends(const QString &packageName,QString architecture);
+    QList<QString> getAllDepends(const QString &packageName, const QString &architecture);
 
     /**
      * @brief refreshPage 刷新当前的页面
@@ -436,12 +457,12 @@ private:
      * @param packages 要添加的包
      * @param allPackageSize 要添加的包的数量
      */
-    void appendNoThread(QStringList packages, int allPackageSize);
+    void appendNoThread(const QStringList &packages, int allPackageSize);
 
     /**
      * @brief checkInvalid 检查有效文件的数量
      */
-    void checkInvalid(QStringList packages);
+    void checkInvalid(const QStringList &packages);
 
     /**
      * @brief dealInvalidPackage 处理无效的安装包
@@ -450,7 +471,7 @@ private:
      *   true   : 文件能打开
      *   fasle  : 文件不在本地或无权限
      */
-    bool dealInvalidPackage(QString packagePath);
+    bool dealInvalidPackage(const QString &packagePath);
 
     /**
      * @brief dealPackagePath 处理包的路径
@@ -460,7 +481,7 @@ private:
      *      1： 相对路径             --------> 转化为绝对路径
      *      2： 包的路径中存在空格     --------> 使用软链接，链接到/tmp下
      */
-    QString dealPackagePath(QString packagePath);
+    QString dealPackagePath(const QString &packagePath);
 
 private slots:
     /**
@@ -476,7 +497,7 @@ private:
      * @return true 是黑名单应用
      * @return false 不是黑名单应用
      */
-    bool isBlackApplication(QString applicationName);
+    bool isBlackApplication(const QString &applicationName);
 
     /**
      * @brief 获取当前黑名单应用列表
@@ -485,14 +506,10 @@ private:
     void getBlackApplications();
 
 private:
-
-    //安装程序后端指针(异步加载)
-    QFuture<QApt::Backend *> m_backendFuture;           
-
     //存放包路径的列表
-    QList<QString> m_preparedPackages       = {};   
+    QList<QString> m_preparedPackages       = {};
 
-    //存放包MD5的集合       
+    //存放包MD5的集合
     QSet<QByteArray> m_appendedPackagesMd5  = {};
 
     QMap<QString, QByteArray> m_allPackages; //存放有效包路径及md5，避免二次获取消耗时间
@@ -539,7 +556,7 @@ private:
     int m_DealDependIndex = -1;
 
     //下载依赖的线程
-    DealDependThread *m_installWineThread        = nullptr;    
+    DealDependThread *m_installWineThread        = nullptr;
 
     /**
      * @brief m_dependInstallMark wine依赖下标的标记
