@@ -1,14 +1,15 @@
-﻿// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+﻿// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "deblistmodel.h"
 #include "manager/packagesmanager.h"
 #include "manager/PackageDependsStatus.h"
+#include "packageanalyzer.h"
 #include "view/pages/AptConfigMessage.h"
 #include "view/pages/settingdialog.h"
 #include "utils/utils.h"
-
+#include "singleInstallerApplication.h"
 
 #include <DDialog>
 #include <DSysInfo>
@@ -77,7 +78,7 @@ const QStringList DebListModel::netErrors()
     return errorDetails;
 }
 
-const QString DebListModel::workerErrorString(const int errorCode, const QString errorInfo)
+const QString DebListModel::workerErrorString(const int errorCode, const QString &errorInfo)
 {
     switch (errorCode) {
     case FetchError:
@@ -131,6 +132,9 @@ void DebListModel::initAppendConnection()
     //添加的包是无效的包
     connect(m_packagesManager, &PackagesManager::signalInvalidPackage, this, &DebListModel::signalInvalidPackage);
 
+    //添加的包是无效的ddim
+    connect(m_packagesManager, &PackagesManager::signalNotDdimProcess, this, &DebListModel::signalNotDdimProcess);
+
     //添加的包不在本地
     connect(m_packagesManager, &PackagesManager::signalNotLocalPackage, this, &DebListModel::signalNotLocalPackage);
 
@@ -211,7 +215,7 @@ void DebListModel::initConnections()
     initInstallConnections();
 }
 
-void DebListModel::slotDealDependResult(int authType, int dependIndex, QString dependName)
+void DebListModel::slotDealDependResult(int authType, int dependIndex, const QString &dependName)
 {
     m_brokenDepend = dependName;
     switch (authType) {
@@ -368,7 +372,7 @@ void DebListModel::slotUninstallPackage(const int index)
     if (!debFile.isValid())
         return;
     const QStringList rdepends = m_packagesManager->packageReverseDependsList(debFile.packageName(), debFile.architecture()); //检查是否有应用依赖到该包
-    Backend *backend = m_packagesManager->m_backendFuture.result();
+    Backend *backend = PackageAnalyzer::instance().backendPtr();
     for (const auto &r : rdepends) {                                        // 卸载所有依赖该包的应用（二者的依赖关系为depends）
         if (backend->package(r)) {
             // 更换卸载包的方式，remove卸载不卸载完全会在影响下次安装的依赖判断。
@@ -426,6 +430,49 @@ void DebListModel::removePackage(const int idx)
     m_packagesManager->removePackage(idx);       //在packageManager中删除标记的下标
 }
 
+int DebListModel::checkInstallStatus(const QString &package_path)
+{
+    return m_packagesManager->checkInstallStatus(package_path);
+}
+
+int DebListModel::checkDependsStatus(const QString &package_path)
+{
+    return m_packagesManager->checkDependsStatus(package_path).status;
+}
+
+int DebListModel::checkDigitalSignature(const QString &package_path)
+{
+    const auto stat = m_packagesManager->checkDependsStatus(package_path); //获取包的依赖状态
+    if (stat.isBreak() || stat.isAuthCancel())
+        return Utils::VerifySuccess;
+    SettingDialog dialog;
+    m_isDigitalVerify = dialog.isDigitalVerified();
+    int digitalSigntual = Utils::Digital_Verify(package_path); //判断是否有数字签名
+    if (m_isDevelopMode && !m_isDigitalVerify) { //开发者模式且未设置验签功能
+        return Utils::VerifySuccess;
+    } else if (m_isDevelopMode && m_isDigitalVerify) { //开发者模式且设置验签功能
+        return digitalSigntual;
+    } else { //非开发者模式
+        return digitalSigntual;
+    }
+}
+
+QStringList DebListModel::getPackageInfo(const QString &package_path)
+{
+    return m_packagesManager->getPackageInfo(package_path);
+}
+
+QString DebListModel::getInstallErrorMessage()
+{
+    if (m_currentTransaction)
+        return m_currentTransaction->errorString();
+    return "faild";
+}
+
+QString DebListModel::checkPackageValid(const QString &package_path)
+{
+    return m_packagesManager->checkPackageValid(QStringList(package_path));
+}
 
 void DebListModel::slotAppendPackage(QStringList package)
 {
@@ -642,12 +689,11 @@ void DebListModel::slotDependsInstallTransactionFinished()//依赖安装关系
 
     const auto transExitStatus = transaction->exitStatus();
 
-    if (transExitStatus) qWarning() << transaction->error() << transaction->errorDetails() << transaction->errorString();     //transaction发生错误
-
     if (transExitStatus) {
         // record error
         // 记录错误原因和错误代码
         // 修改map存储的数据格式，将错误原因与错误代码与包绑定，而非与下标绑定
+        qWarning() << transaction->error() << transaction->errorDetails() << transaction->errorString(); //向终端打印错误
         m_packageFailCode[m_operatingPackageMd5] = transaction->error();
         m_packageFailReason[m_operatingPackageMd5] = transaction->errorString();
         refreshOperatingPackageStatus(Failed);                                  // 刷新操作状态
@@ -680,7 +726,7 @@ void DebListModel::checkBoxStatus()
 {
     QTime startTime = QTime::currentTime();                                      //获取弹出的时间
     Transaction *transation = nullptr;
-    auto *const backend = m_packagesManager->m_backendFuture.result();
+    auto *const backend = PackageAnalyzer::instance().backendPtr();
     transation = backend->commitChanges();
 
     QTime stopTime = QTime::currentTime();
@@ -713,7 +759,7 @@ void DebListModel::installDebs()
     emit signalStartInstall();
 
     // fetch next deb
-    auto *const backend = m_packagesManager->m_backendFuture.result();
+    auto *const backend = PackageAnalyzer::instance().backendPtr();
     if (!backend)
         return;
 
@@ -824,8 +870,45 @@ void DebListModel::digitalVerifyFailed(ErrorCode errorCode)
     }
 }
 
+void DebListModel::showNoDigitalErrWindowInDdimProcess(void (DebListModel::*failedFunction)())
+{
+    DDialog *Ddialog = new DDialog(); //弹出窗口
+    Ddialog->setModal(true);
+    Ddialog->setWindowFlag(Qt::WindowStaysOnTopHint); //窗口一直置顶
+    Ddialog->setTitle(tr("Unable to install"));
+    Ddialog->setIcon(QIcon::fromTheme("di_popwarning"));
+    Ddialog->addButton(QString(tr("OK", "button")), true, DDialog::ButtonNormal); //添加确认按钮
+
+    auto fullPath = m_packagesManager->package(m_operatingIndex);
+    QFileInfo info(fullPath);
+    Ddialog->setMessage(QString(tr("Failed to install %1: no valid digital singature").arg(info.fileName())));
+
+    //消息框reject后的操作，包括点击取消按钮、关闭图标、按ESC退出
+    std::function<void(void)> rejectOperate = [this, Ddialog, failedFunction]() {
+        (this->*failedFunction)();
+        Ddialog->deleteLater();
+    };
+
+    //取消按钮
+    QPushButton *btnOk = qobject_cast<QPushButton *>(Ddialog->getButton(0));
+    connect(btnOk, &DPushButton::clicked, Ddialog, &DDialog::reject);
+
+    //关闭图标
+    connect(Ddialog, &DDialog::aboutToClose, Ddialog, &DDialog::reject);
+
+    //ESC退出
+    connect(Ddialog, &DDialog::rejected, rejectOperate);
+
+    Ddialog->exec(); //显示弹窗
+}
+
 void DebListModel::showNoDigitalErrWindow()
 {
+    if (SingleInstallerApplication::mode == SingleInstallerApplication::DdimChannel) {
+        showNoDigitalErrWindowInDdimProcess(&DebListModel::slotNoDigitalSignature);
+        return;
+    }
+
     //批量安装时，如果不是最后一个包，则不弹窗，只记录详细错误原因。
     if (m_operatingIndex < m_packagesManager->m_preparedPackages.size() - 1) {
         digitalVerifyFailed(NoDigitalSignature);//刷新安装错误，并记录错误原因
@@ -843,7 +926,7 @@ void DebListModel::showNoDigitalErrWindow()
     Ddialog->show();    //显示弹窗
 
     //消息框reject后的操作，包括点击取消按钮、关闭图标、按ESC退出
-    std::function<void(void)> rejectOperate = [this, Ddialog](){
+    std::function<void(void)> rejectOperate = [this, Ddialog]() {
         this->slotNoDigitalSignature();
         Ddialog->deleteLater();
     };
@@ -865,9 +948,13 @@ void DebListModel::showNoDigitalErrWindow()
     connect(btnProceedControlCenter, &DPushButton::clicked, Ddialog, &DDialog::deleteLater);
 }
 
-
 void DebListModel::showDigitalErrWindow()
 {
+    if (SingleInstallerApplication::mode == SingleInstallerApplication::DdimChannel) {
+        showNoDigitalErrWindowInDdimProcess(&DebListModel::slotDigitalSignatureError);
+        return;
+    }
+
     //批量安装时，如果不是最后一个包，则不弹窗，只记录详细错误原因。
     if (m_operatingIndex < m_packagesManager->m_preparedPackages.size() - 1) {
         digitalVerifyFailed(DigitalSignatureError);     //刷新安装错误，并记录错误原因
@@ -894,7 +981,7 @@ void DebListModel::showDigitalErrWindow()
     btnOK->setFocus();
 
     //窗口退出操作，包括所有可以退出此窗口的操作
-    std::function<void(void)> exitOperate = [this, Ddialog](){
+    std::function<void(void)> exitOperate = [this, Ddialog]() {
         this->slotDigitalSignatureError();
         Ddialog->deleteLater();
     };
@@ -968,19 +1055,47 @@ void DebListModel::slotNoDigitalSignature()
 
 void DebListModel::slotShowDevelopModeWindow()
 {
-    //弹出设置 通用窗口
-    QString command = " dbus-send --print-reply "
-                      "--dest=com.deepin.dde.ControlCenter "
-                      "/com/deepin/dde/ControlCenter "
-                      "com.deepin.dde.ControlCenter.ShowModule "
-                      "\"string:commoninfo\"";
+    // 弹出设置 通用窗口
+
+    //1.读取系统版本号
     QProcess *unlock = new QProcess(this);
-
-    connect(unlock, static_cast<void (QProcess::*)(int)>(&QProcess::finished), unlock, &QProcess::deleteLater);
-
-    unlock->startDetached(command);
+    unlock->start("lsb_release", {"-r"});
     unlock->waitForFinished();
-    return;
+    auto output = unlock->readAllStandardOutput();
+    auto str = QString::fromUtf8(output);
+    QRegExp re("\t.+\n");
+    QString osVerStr;
+    if (re.indexIn(str) > -1) {
+        auto result = re.cap(0);
+        osVerStr = result.remove(0, 1).remove(result.size() - 1, 1);
+        qInfo() << "lsb_release -r:" << output;
+        qInfo() << "OS version:" << osVerStr;
+    }
+
+    //2.打开控制中心
+    if (osVerStr == "20") { // V20模式
+        QString command = "dbus-send --print-reply "
+                          "--dest=com.deepin.dde.ControlCenter "
+                          "/com/deepin/dde/ControlCenter "
+                          "com.deepin.dde.ControlCenter.ShowModule "
+                          "\"string:commoninfo\"";
+        unlock->startDetached(command);
+        unlock->waitForFinished();
+    } else if (osVerStr == "23") { // V23模式
+        if (unlock->exitCode() != QProcess::NormalExit) {
+            QString command = "dbus-send --print-reply "
+                              "--dest=org.deepin.dde.ControlCenter1 "
+                              "/org/deepin/dde/ControlCenter1 "
+                              "org.deepin.dde.ControlCenter1.ShowPage "
+                              "\"string:commoninfo\"";
+            unlock->startDetached(command);
+            unlock->waitForFinished();
+        }
+    } else {
+        qWarning() << "Unknown OS version, connot open dde-control-center";
+    }
+
+    unlock->deleteLater();
 }
 
 void DebListModel::checkSystemVersion()
@@ -1037,8 +1152,6 @@ void DebListModel::checkSystemVersion()
     }
 
 #endif
-
-
 }
 
 bool DebListModel::checkDigitalSignature()
@@ -1096,9 +1209,9 @@ void DebListModel::installNextDeb()
 {
     m_packagesManager->resetPackageDependsStatus(m_operatingStatusIndex); //刷新软件包依赖状态
     auto dependStatus = m_packagesManager->getPackageDependsStatus(m_operatingStatusIndex);
-    if(dependStatus.isAvailable()) { //存在没有安装的依赖包，则进入普通安装流程执行依赖安装
+    if (dependStatus.isAvailable()) { //存在没有安装的依赖包，则进入普通安装流程执行依赖安装
         installDebs();
-    } else if(dependStatus.status >= DependsBreak) { //安装前置条件不满足，无法处理
+    } else if (dependStatus.status >= DependsBreak) { //安装前置条件不满足，无法处理
         refreshOperatingPackageStatus(Failed);
         bumpInstallIndex();
         return;
@@ -1123,7 +1236,7 @@ void DebListModel::rmdir()
     }
 }
 
-bool DebListModel::checkTemplate(QString debPath)
+bool DebListModel::checkTemplate(const QString &debPath)
 {
     rmdir();
     getDebian(debPath);
@@ -1145,7 +1258,7 @@ bool DebListModel::mkdir()
     return true;
 }
 
-void DebListModel::getDebian(QString debPath)
+void DebListModel::getDebian(const QString &debPath)
 {
     if (!mkdir()) {                                                             //创建临时路径
         qWarning() << "check error mkdir" << tempPath << "failed";              //创建失败
@@ -1334,13 +1447,13 @@ void DebListModel::slotConfigReadOutput(const char *buffer, int length, bool isC
     }
 }
 
-void DebListModel::slotConfigInputWrite(QString str)
+void DebListModel::slotConfigInputWrite(const QString &str)
 {
     m_procInstallConfig->pty()->write(str.toUtf8());                                          //将用户输入的配置项写入到配置安装进程中。
     m_procInstallConfig->pty()->write("\n");                                                  //写入换行，配置生效
 }
 
-void DebListModel::slotCheckInstallStatus(QString installInfo)
+void DebListModel::slotCheckInstallStatus(const QString &installInfo)
 {
     // 判断当前的信息是否是错误提示信息
     if (installInfo.contains("Error executing command as another user: Request dismissed")) {
@@ -1358,16 +1471,16 @@ void DebListModel::slotCheckInstallStatus(QString installInfo)
     }
 }
 
-bool DebListModel::recheckPackagePath(QString packagePath) const
+bool DebListModel::recheckPackagePath(const QString &packagePath) const
 {
     QFile packagePathFile(packagePath);
     do {
-        if (packagePathFile.readLink().isEmpty()) {
+        if (packagePathFile.symLinkTarget().isEmpty()) {
             if (packagePathFile.exists()) {
                 return true;
             }
         } else {
-            QFile realPath(packagePathFile.readLink());
+            QFile realPath(packagePathFile.symLinkTarget());
             if (realPath.exists() && packagePathFile.exists()) {
                 return true;
             }
@@ -1419,7 +1532,7 @@ void DebListModel::showProhibitWindow()
     btnOK->setFocus();
 
     //窗口退出操作，包括所有可以退出此窗口的操作
-    std::function<void(void)> exitOperate = [this, Ddialog](){
+    std::function<void(void)> exitOperate = [this, Ddialog]() {
         this->slotShowProhibitWindow();
         Ddialog->deleteLater();
     };
