@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -66,7 +66,7 @@ public:
      * @param errorInfo 库返回的或自定义的安装错误的原因
      * @return 要显示的安装失败的原因
      */
-    static const QString workerErrorString(const int errorCode, const QString errorInfo);
+    static const QString workerErrorString(const int errorCode, const QString &errorInfo);
     /**
      * @brief The PackageRole enum
      * 包的各种数据角色
@@ -258,6 +258,36 @@ public:
      */
     void removePackage(const int idx);
 
+    /**
+     * @brief checkPackageDigitalSignature 查找指定包安装状态
+     * @param package_path 路径
+     */
+    int checkInstallStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包依赖
+     * @param package_path 路径
+     */
+    int checkDependsStatus(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包数字签名
+     * @param package_path 路径
+     */
+    int checkDigitalSignature(const QString &package_path);
+    /**
+     * @brief searchPackageInstallInfo 查找指定包信息
+     * @param package_path 路径
+     */
+    QStringList getPackageInfo(const QString &package_path);
+    /**
+     * @brief getInstallErrorMessage 安装错误信息
+     */
+    QString getInstallErrorMessage();
+    /**
+     * @brief checkPackageValid 查找指定包信息
+     * @param package_path 路径
+     */
+    QString checkPackageValid(const QString &package_path);
+
 signals:
     /**
      * @brief signalLockForAuth  授权框弹出后 禁用按钮  授权框取消后，启用按钮
@@ -340,6 +370,11 @@ signals:
      */
     void signalInvalidPackage();
 
+    /**
+     * @brief signalNotDdimProcess 非DDIM处理流程
+     */
+    void signalNotDdimProcess();
+
     /**
      * @brief signalNotLocalPackage 包不在本地的信号
      *
@@ -443,7 +478,7 @@ public slots:
      * @param dependIndex   依赖包的index（因为这个包的依赖不被满足）
      * @param dependName    发生依赖安装失败的依赖名称
      */
-    void slotDealDependResult(int authType, int dependIndex, QString dependName);
+    void slotDealDependResult(int authType, int dependIndex, const QString &dependName);
 
 public slots:
     /**
@@ -461,7 +496,7 @@ public slots:
      * @brief slotConfigInputWrite 配置的输入数据处理
      * @param str 输入的数据（一般是输入的选项）
      */
-    void slotConfigInputWrite(QString str);
+    void slotConfigInputWrite(const QString &str);
 
     /**
      * @brief slotCheckInstallStatus 根据命令返回的消息判断安装状态
@@ -469,7 +504,7 @@ public slots:
      * 如果命令返回的信息是Cannot run program deepin-deb-installer-dependsInstall: No such file or directory
      * 意味着当前/usr/bin下没有deepin-deb-installer-dependsInstall命令，此版本有问题，需要重新安装deepin-deb-installer-dependsInstall命令
      */
-    void slotCheckInstallStatus(QString str);
+    void slotCheckInstallStatus(const QString &str);
 
 private slots:
 
@@ -606,6 +641,11 @@ private:
      */
     void showDevelopDigitalErrWindow(ErrorCode code);
 
+    /**
+     * @brief showNoDigitalErrWindowInDdimProcess DDIM流程下的签名错误弹窗
+     */
+    void showNoDigitalErrWindowInDdimProcess(void (DebListModel::*failedFunction)());
+
     /**
      * @brief showProhibitWindow 弹出数字签名校验错误的错误弹窗
      */
@@ -633,13 +673,13 @@ private:
      * @param debPath   包的路径
      * @return  是否需要配置
      */
-    bool checkTemplate(QString debPath);
+    bool checkTemplate(const QString &debPath);
 
     /**
      * @brief getDebian    获取包的DEBIAN文件
      * @param debPath      包的路径
      */
-    void getDebian(QString debPath);
+    void getDebian(const QString &debPath);
 
     /**
      * @brief mkdir     创建临时目录 ，存放DEBIAN文件
@@ -676,7 +716,7 @@ private:
      *         true : 文件存在
      *         false: 文件不存在
      */
-    bool recheckPackagePath(QString packagePath) const;
+    bool recheckPackagePath(const QString &packagePath) const;
 
 private:
     /**
