@@ -1,54 +1,101 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
 <context>
     <name>AptConfigMessage</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="98"/>
+        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
         <source>Enter the number to configure: </source>
         <translation>Voer het nummer in om in te stellen: </translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="103"/>
+        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>Oké</translation>
     </message>
 </context>
+<context>
+    <name>BackendProcessPage</name>
+    <message>
+        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
+        <source>Loading packages...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
+        <source>%1/%2 loaded</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
+        <source>Initializing...</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>DdimErrorPage</name>
+    <message>
+        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
+        <source>OK</source>
+        <translation>Oké</translation>
+    </message>
+</context>
 <context>
     <name>DebInstaller</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="100"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="102"/>
         <source>Package Installer</source>
         <translation>Pakketinstallatie</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="110"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="288"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="131"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="539"/>
+        <source>Installing other packages... Please open it later.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
+        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
+        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="547"/>
+        <source>No deb packages found. Please check the folder.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="625"/>
         <source>The deb package may be broken</source>
         <translation>Het deb-pakket is mogelijk beschadigd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="296"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="633"/>
         <source>You can only install local deb packages</source>
         <translation>Je kunt alleen lokale deb-pakketten installeren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="305"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="647"/>
         <source>Already Added</source>
         <translation>Reeds toegevoegd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="314"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="656"/>
         <source>%1 does not exist, please reselect</source>
         <translation>%1 bestaat niet - kies een ander bestand</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="425"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="331"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="663"/>
+        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="792"/>
         <source>Bulk Install</source>
         <translation>Alles installeren</translation>
     </message>
@@ -56,119 +103,126 @@
 <context>
     <name>DebListModel</name>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="101"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="118"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="85"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="102"/>
         <source>Installation failed, please check your network connection</source>
         <translation>Installatie mislukt: controleer je internetverbinding.</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="103"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
         <source>Installation failed, please check for updates in Control Center</source>
         <translation>Installatie mislukt: controleer op updates in het instellingencentrum.</translation>
     </message>
     <message>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="90"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="94"/>
         <location filename="../src/deb-installer/model/deblistmodel.cpp" line="106"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="110"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="122"/>
         <source>Installation failed, insufficient disk space</source>
         <translation>Installatie mislukt: onvoldoende schijfruimte.</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
         <source>No digital signature</source>
         <translation>Geen digitale handtekening</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="131"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="115"/>
         <source>Invalid digital signature</source>
         <translation>Ongeldige digitale handtekening</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="138"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="577"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1386"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="122"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="607"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1524"/>
         <source>The administrator has set policies to prevent installation of this package</source>
         <translation>De beheerder voert een beleid wat voorkomt dat dit pakket geïnstalleerd mag worden</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="143"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
         <source>Installation Failed</source>
         <translation>Installatie mislukt</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="581"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="611"/>
         <source>Failed to install %1</source>
         <translation>%1 kan niet worden geïnstalleerd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="852"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="883"/>
+        <source>Failed to install %1: no valid digital singature</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="919"/>
         <source>Unable to install - no digital signature</source>
         <translation>Kan niet installeren: geen digitale handtekening</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="853"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="920"/>
         <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
         <translation>Ga naar de systeeminstellingen, schakel de ontwikkelaarsmodus in en probeer het opnieuw. Wil je doorgaan?</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="856"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="923"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="857"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="924"/>
         <source>Proceed</source>
         <comment>button</comment>
         <translation>Doorgaan</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="898"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1388"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="879"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="976"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1526"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>Oké</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="926"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1012"/>
         <source>This package does not have a valid digital signature. Continue with the installation?</source>
         <translation>Dit pakket bevat geen geldige ondertekening. Weet je zeker dat je wilt doorgaan?</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="928"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1014"/>
         <source>Cancel</source>
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="929"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1015"/>
         <source>Continue</source>
         <comment>button</comment>
         <translation>Doorgaan</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="895"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1385"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="877"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="973"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1523"/>
         <source>Unable to install</source>
         <translation>Installeren niet mogelijk</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="896"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="974"/>
         <source>This package does not have a valid digital signature</source>
         <translation>Dit pakket bevat geen geldige ondertekening</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="582"/>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="587"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="612"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="617"/>
         <source>Broken dependencies: %1</source>
         <translation>Niet-voldane afhankelijkheden: %1</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="135"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="119"/>
         <source>Authentication failed</source>
         <translation>Authenticatie mislukt</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="575"/>
+        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="605"/>
         <source>Unmatched package architecture</source>
         <translation>Pakketarchitectuur komt niet overeen</translation>
     </message>
@@ -189,84 +243,121 @@
 <context>
     <name>MultipleInstallPage</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="46"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
         <source>Show details</source>
         <translation>Informatie tonen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="46"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
         <source>Collapse</source>
         <comment>button</comment>
         <translation>Inklappen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="184"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
         <source>Install</source>
         <comment>button</comment>
         <translation>Installeren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="185"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
         <source>Done</source>
         <comment>button</comment>
         <translation>Klaar</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="187"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
         <source>Back</source>
         <comment>button</comment>
         <translation>Terug</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="477"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="464"/>
         <source>Dependencies in the repository</source>
         <translation>Afhankelijkheden in de pakketbron</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="483"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="470"/>
         <source>Missing dependencies</source>
         <translation>Ontbrekende afhankelijkheden</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="532"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="519"/>
         <source>Installing dependencies: %1</source>
         <translation>Bezig met installeren van afhankelijkheden: %1</translation>
     </message>
 </context>
 <context>
-    <name>PackagesListDelegate</name>
+    <name>PackageSelectItem</name>
     <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="74"/>
-        <source>Installing</source>
-        <translation>Bezig met installeren</translation>
-    </message>
-    <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="78"/>
-        <source>Installed</source>
-        <translation>Geïnstalleerd</translation>
-    </message>
-    <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="86"/>
-        <source>Failed</source>
-        <translation>Mislukt</translation>
-    </message>
-    <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="82"/>
-        <source>Waiting</source>
-        <translation>Bezig met wachten</translation>
-    </message>
-    <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="247"/>
+        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
         <source>Same version installed</source>
         <translation>Dezelfde versie is geïnstalleerd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="250"/>
+        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
+        <source>Earlier version installed: %1</source>
+        <translation>Oudere versie geïnstalleerd: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
         <source>Later version installed: %1</source>
         <translation>Nieuwere versie geïnstalleerd: %1</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="253"/>
+        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
+        <source>Unmatched package architecture</source>
+        <translation>Pakketarchitectuur komt niet overeen</translation>
+    </message>
+</context>
+<context>
+    <name>PackageSelectView</name>
+    <message>
+        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
+        <source>Select all</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
+        <source>Install</source>
+        <comment>button</comment>
+        <translation>Installeren</translation>
+    </message>
+</context>
+<context>
+    <name>PackagesListDelegate</name>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
+        <source>Installing</source>
+        <translation>Bezig met installeren</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
+        <source>Installed</source>
+        <translation>Geïnstalleerd</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
+        <source>Failed</source>
+        <translation>Mislukt</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
+        <source>Waiting</source>
+        <translation>Bezig met wachten</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="233"/>
+        <source>Same version installed</source>
+        <translation>Dezelfde versie is geïnstalleerd</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="236"/>
+        <source>Later version installed: %1</source>
+        <translation>Nieuwere versie geïnstalleerd: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="239"/>
         <source>Earlier version installed: %1</source>
         <translation>Oudere versie geïnstalleerd: %1</translation>
     </message>
@@ -274,7 +365,7 @@
 <context>
     <name>PackagesListView</name>
     <message>
-        <location filename="../src/deb-installer/model/packagelistview.cpp" line="158"/>
+        <location filename="../src/deb-installer/model/packagelistview.cpp" line="166"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
@@ -282,9 +373,9 @@
 <context>
     <name>QApplication</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="43"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="57"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="58"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
         <source>Collapse</source>
         <comment>button</comment>
         <translation>Inklappen</translation>
@@ -293,12 +384,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="21"/>
+        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
         <source>Basic</source>
         <translation>Algemeen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="22"/>
+        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
         <source>Check digital signatures if the developer mode is enabled</source>
         <translation>Ondertekeningen controleren als ontwikkelaarsmodus is ingeschakeld</translation>
     </message>
@@ -306,120 +397,120 @@
 <context>
     <name>SingleInstallPage</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="726"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="708"/>
         <source>Collapse</source>
         <translation>Inklappen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="356"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="822"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="986"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="804"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="967"/>
         <source>Reinstall</source>
         <translation>Opnieuw installeren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="825"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="989"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="807"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="970"/>
         <source>Later version installed: %1</source>
         <translation>Nieuwere versie geïnstalleerd: %1</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="827"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="991"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="809"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="972"/>
         <source>Downgrade</source>
         <translation>Afwaarderen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="830"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="994"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="812"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="975"/>
         <source>Earlier version installed: %1</source>
         <translation>Oudere versie geïnstalleerd: %1</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="895"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="877"/>
         <source>Installing dependencies: %1</source>
         <translation>Bezig met installeren van afhankelijkheden: %1</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1031"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1012"/>
         <source>Failed to install %1</source>
         <translation>%1 kan niet worden geïnstalleerd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="190"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
         <source>Version: </source>
         <translation>Versie:</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="348"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
         <source>Install</source>
         <comment>button</comment>
         <translation>Installeren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="352"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
         <source>Remove</source>
         <comment>button</comment>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="360"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>Oké</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="364"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
         <source>Back</source>
         <comment>button</comment>
         <translation>Terug</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="368"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
         <source>Done</source>
         <comment>button</comment>
         <translation>Klaar</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="702"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="680"/>
         <source>Installed successfully</source>
         <translation>Installatie voltooid</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="685"/>
         <source>Uninstalled successfully</source>
         <translation>Verwijderd</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="717"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="699"/>
         <source>Uninstall Failed</source>
         <translation>Opnieuw installeren mislukt</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="746"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="728"/>
         <source>Dependencies in the repository</source>
         <translation>Afhankelijkheden in de pakketbron</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="752"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="734"/>
         <source>Missing dependencies</source>
         <translation>Ontbrekende afhankelijkheden</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="832"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="996"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="814"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="977"/>
         <source>Update</source>
         <comment>button</comment>
         <translation>Bijwerken</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
         <source>Name: </source>
         <translation>Naam:</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="821"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="985"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
         <source>Same version installed</source>
         <translation>Dezelfde versie is geïnstalleerd</translation>
     </message>
@@ -427,16 +518,16 @@
 <context>
     <name>SingleInstallPage_Install</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="57"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="548"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="573"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="701"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
         <source>Show details</source>
         <translation>Informatie tonen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="43"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="58"/>
+        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
         <source>Show dependencies</source>
         <translation>Afhankelijkheden tonen</translation>
     </message>
@@ -444,8 +535,8 @@
 <context>
     <name>SingleInstallPage_Uninstall</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="598"/>
-        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="706"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
+        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
         <source>Show details</source>
         <translation>Informatie tonen</translation>
     </message>
@@ -453,36 +544,36 @@
 <context>
     <name>UninstallConfirmPage</name>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="29"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
         <source>Show related packages</source>
         <translation>Gerelateerde pakketten tonen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="29"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
         <source>Collapse</source>
         <comment>button</comment>
         <translation>Inklappen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="50"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="52"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
         <source>Confirm</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="126"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
         <source>Are you sure you want to uninstall %1?
 All dependencies will also be removed</source>
         <translation>Weet je zeker dat je %1 wilt verwijderen?
 Alle afhankelijkheden worden eveneens verwijderd.</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="128"/>
+        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
         <source>Are you sure you want to uninstall %1?
 The system or other applications may not work properly</source>
         <translation>Weet je zeker dat je %1 wilt verwijderen?
@@ -492,15 +583,15 @@ Het systeem of andere programma&apos;s werken dan mogelijk niet goed meer.</tran
 <context>
     <name>main</name>
     <message>
-        <location filename="../src/deb-installer/main.cpp" line="61"/>
-        <location filename="../src/deb-installer/main.cpp" line="62"/>
+        <location filename="../src/deb-installer/main.cpp" line="47"/>
+        <location filename="../src/deb-installer/main.cpp" line="48"/>
         <source>Package Installer</source>
         <translation>Pakketinstallatie</translation>
     </message>
     <message>
-        <location filename="../src/deb-installer/main.cpp" line="63"/>
+        <location filename="../src/deb-installer/main.cpp" line="49"/>
         <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
         <translation>Pakketinstallatie is een programma dat gebruikers helpt bij het installeren van lokale software.</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
